@@ -52,10 +52,6 @@ pub(crate) fn parse_rational(number: Pair<Rule>) -> BigRational {
     )
 }
 
-pub(crate) fn parse_usize(number: Pair<Rule>) -> usize {
-    usize::from_str(number.as_str()).unwrap()
-}
-
 pub(crate) fn parse_string(string: Pair<Rule>) -> String {
     match string.as_rule() {
         Rule::string => {
@@ -77,3 +73,41 @@ pub(crate) fn parse_string(string: Pair<Rule>) -> String {
         _ => string.as_str().trim().to_string(),
     }
 }
+
+/// Counts the number of decimals in an amount as defined in the grammar
+pub(crate) fn count_decimals(amount: &str) -> usize {
+    let mut parsed = GrammarParser::parse(Rule::money, amount)
+        .unwrap()
+        .next()
+        .unwrap()
+        .into_inner();
+    let number = parsed.next().unwrap();
+
+    let number = match number.as_rule() {
+        Rule::number => number,
+        //Rule::currency is the only other option
+        _ => parsed.next().unwrap(),
+    };
+
+    assert_eq!(number.as_rule(), Rule::number);
+
+    let text = number.as_str();
+    // dbg!(text);
+    if text.contains(".") {
+        number.as_str().split(".").last().unwrap().len()
+    } else {
+        0
+    }
+}
+
+#[cfg(test)]
+mod tests {
+    use crate::parser::utils::count_decimals;
+
+    #[test]
+    fn count_decimals_test() {
+        assert_eq!(count_decimals("150.4 EUR"), 1);
+        assert_eq!(count_decimals("150 EUR"), 0);
+        assert_eq!(count_decimals("EUR 150.4"), 1);
+    }
+}
